@@ -1,11 +1,9 @@
 from typing import Optional, Union
 
-from ts_t1_validator.utils import \
-    is_number, is_int
+from ts_t1_validator.utils import is_number, is_int
 from ts_t1_validator.validators.exceptions import ValidationException
 from ts_t1_validator.validators.rules.abstract_rule import ValidationRule
 from ts_t1_validator.models.enums.impression_pacing_type import ImpressionPacingTypeEnum
-from ts_t1_validator.models.enums.input_type import InputTypeEnum
 from ts_t1_validator.models.enums.pacing_interval import PacingIntervalEnum
 
 
@@ -13,12 +11,10 @@ class ImpressionPacingTypeRule(ValidationRule):
     def __init__(self,
                  impression_pacing_type: ImpressionPacingTypeEnum,
                  impression_pacing_amount: Optional[Union[int, float]],
-                 impression_pacing_interval: PacingIntervalEnum,
-                 input_type: InputTypeEnum):
+                 impression_pacing_interval: PacingIntervalEnum):
         self.impression_pacing_type = impression_pacing_type
         self.impression_pacing_amount = impression_pacing_amount
         self.impression_pacing_interval = impression_pacing_interval
-        self.input_type = input_type
 
     def execute(self):
         if self.impression_pacing_type is not ImpressionPacingTypeEnum.UNDEFINED:
@@ -54,12 +50,8 @@ class ImpressionPacingTypeRule(ValidationRule):
             """
             if self.impression_pacing_type in [ImpressionPacingTypeEnum.ASAP,
                                                ImpressionPacingTypeEnum.EVEN]:
-                if self.input_type is InputTypeEnum.FIXED:
-                    if not is_int(self.impression_pacing_amount):
-                        raise ValidationException("for input_type='fixed' impression_pacing_amount must be an integer")
-                elif self.input_type is InputTypeEnum.PERCENTAGE:
-                    if not is_number(self.impression_pacing_amount):
-                        raise ValidationException("for input_type='percentage' impression_pacing_amount must be a float")
+                if not is_number(self.impression_pacing_amount):
+                    raise ValidationException("impression_pacing_amount must be a float")
         else:
             if self.impression_pacing_interval is not PacingIntervalEnum.UNDEFINED:
                 raise ValidationException("impression_pacing_type is required when impression_pacing_interval is defined")
